/*
  ==============================================================================

   This file is part of the JUCE tutorials.
   Copyright (c) 2020 - Raw Material Software Limited

   The code included in this file is provided under the terms of the ISC license
   http://www.isc.org/downloads/software-support-policy/isc-license. Permission
   To use, copy, modify, and/or distribute this software for any purpose with or
   without fee is hereby granted provided that the above copyright notice and
   this permission notice appear in all copies.

   THE SOFTWARE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES,
   WHETHER EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR
   PURPOSE, ARE DISCLAIMED.

  ==============================================================================
*/

/*******************************************************************************
 The block below describes the properties of this PIP. A PIP is a short snippet
 of code that can be read by the Projucer and used to generate a JUCE project.

 BEGIN_JUCE_PIP_METADATA

 name:             GraphicsTutorial
 version:          1.0.0
 vendor:           JUCE
 website:          http://juce.com
 description:      Explores graphics features.

 dependencies:     juce_core, juce_data_structures, juce_events, juce_graphics,
                   juce_gui_basics
 exporters:        xcode_mac, vs2019, linux_make, xcode_iphone, androidstudio

 type:             Component
 mainClass:        MainComponent

 useLocalCopy:     1

 END_JUCE_PIP_METADATA

*******************************************************************************/


#pragma once

//==============================================================================
/*
    This component lives inside our window, and this is where you should put all
    your controls and content.
*/
class MainComponent   : public juce::Component
{
public:
    //==============================================================================
    MainComponent()
    {
        setSize (600, 400);
    }

    void paint (juce::Graphics& g) override
    {
        g.fillAll (juce::Colours::lightblue);
 
        g.setColour (juce::Colours::darkblue);
        g.setFont (juce::Font ("Times New Roman", 20.0f, juce::Font::italic));
        //g.drawText ("Hello, World!", getLocalBounds(), juce::Justification::centred, true);
        g.drawText ("Hello, World!", 20, 40, 200, 40, juce::Justification::centred, true);
        
        g.setColour (juce::Colours::green);
        g.drawLine (10, 300, 590, 300, 5);

        juce::Rectangle<float> house (300, 120, 200, 170);
        g.fillCheckerBoard (house, 30, 10, juce::Colours::sandybrown, juce::Colours::saddlebrown);

        g.setColour (juce::Colours::yellow);
        g.drawEllipse (getWidth() - 70, 10, 60, 60, 3);

        g.setColour (juce::Colours::red);
 
        Path roof;
        roof.addTriangle (300, 110, 500, 110, 400, 70);
        g.fillPath (roof);
    }

    void resized() override
    {
        // This is called when the MainContentComponent is resized.
        // If you add any child components, this is where you should
        // update their positions.
    }

private:
    //==============================================================================
    JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (MainComponent)
};
